/* 
    Advanced ODS Graphics
    Hands On Workshop

    Solution Set 2 
    New types of information
*/

/*

    Exercise 2.1
    Run the basic plot

*/

proc sgplot data=nasa;
    series x=year y=NASA_outlay / markers;
run;

/*
    Exercise 2.2
    Use BLOCKS to add more information

*/

proc sgplot data=nasa;
*    <keyword> x=year block=party ;
    <keyword> x=year block=party ;
    series x=year y=NASA_outlay / markers;
run;

/*

    Exercise 2.3
    "Fix" the colors so that the FILLTYPE alternates (default is MULTICOLOR)
    between RED for Republicans and BLUE for Democrats
    The color of the first block is set by FILLATTRS 
    And the color of the second block is set by ALTFILLATTRS
    
*/

proc sgplot data=nasa;
*    block x=year block=party / <keyword>=alternate <keyword>=(color=<keyword>) <keyword>=(color=<keyword>);
    block x=year block=party / <keyword>=alternate <keyword>=(color=<keyword>) <keyword>=(color=<keyword>);
    series x=year y=NASA_outlay / markers;
run;

/*

    Exercise 2.4
    "Lighten" the colors by setting the TRANSPARENCY
    Try different transparency percentages until you get one you like
    
*/

proc sgplot data=nasa;
*    block x=year block=party / filltype=alternate 
        fillattrs=(color=red <keyword>=0.5) altfillattrs=(color=blue <keyword>=0.5);
    block x=year block=party / filltype=alternate 
        fillattrs=(color=red <keyword>=0.5) altfillattrs=(color=blue <keyword>=0.5);
    series x=year y=NASA_outlay / markers;
run;

/*

    Exercise 2.5

    We'll create a BUBBLE plot of spending over the years
    The SIZE of the bubble will be determined by the number of missions
    You can try different dataskins
        NONE, CRISP, GLOSS, MATTE, PRESSED, SHEEN

    Set the color of the bubble according to who the 
    president was with the option GROUP= 

*/

proc sgplot data=nasa;
*    <keyword> x=year y=nasa_outlay <keyword>=num_missions 
            / dataskin=<keyword> ;
    <keyword> x=year y=nasa_outlay <keyword>=num_missions 
            / dataskin=<keyword> ;
run;

/*
    Animated GIFs can be created in SAS. 

    --All credit for this macro and this idea goes to Sanjay Matange
    His blog can be found at http://blogs.sas.com/content/graphicallyspeaking

    Any bugs are mine.
--*/

%macro GapMinder(start=, end=, incr=);
  %do year=&start %to &end-5 %by &incr;

    proc sgplot data=nasa noautolegend;
        footnote j=l 'Created using the SGPLOT Procedure';
        footnote2 j=l 'Color represents President in office';
        where ((year >= &year.) and (year <= (&year.+5)));

        bubble x=year y=nasa_outlay size=num_missions
            / group=president datalabel=pgm 
            datalabelattrs=(size=12 weight=bold)
            datalabelpos=topleft
            dataskin=sheen
        ;
	  inset "&year - %eval(&year+4)" / position=bottomright textattrs=(size=30 weight=bold color=lightgray);
      xaxis type=log offsetmin=0.05 offsetmax=0.08 logstyle=linear grid min=1958 max=2015;
      yaxis offsetmin=0.05 offsetmax=0.05 grid min=89 max=22000;
    run;

  %end;
%mend GapMinder;

ods html close;

options papersize=('5 in', '3 in') printerpath=gif animation=start 
        animduration=0.1 animloop=yes noanimoverlay
        nodate nonumber ;
ods printer file='results\GapMinder.gif';
 
ods graphics / width=5in height=3in imagefmt=GIF;

%GapMinder(start=1958, end=2015, incr=1);

options printerpath=gif animation=stop;
ods printer close;

footnote;


ods graphics / reset=all
	imagename="ODS_Graphics_HOW_2";

ods html path="&homedir.\results" (url=none)
         file="HOW2_graphs.html";   

/*

    Exercise 2.6
    Show the total spending (SUM) with a WATERFALL plot that 
    Color the steps (COLORGROUP) of the waterfall according to the President's party 

    Additionally, the value of the Final Tick Bar is boring and unhelpful. Fix this by
    adding the option to set the FINALBARTICKVALUE to "Total Spending"

*/

proc sgplot data=nasa;
*    <keyword> category=president response=NASA_outlay / stat=<keyword> <keyword>=party ;
    <keyword> category=president response=NASA_outlay / stat=<keyword> <keyword>=party;
run;

/*

    Exercise 2.7
    Add a TIP to each of the bars. We'll use two variables Total_spending and Program
    Put a TIPLABEL on them 
    Format the "Space Program" tip AUTO

    Put a DATALABEL on the waterfalls.
    Can you assign a variable as the DATALABEL?

*/

ods graphics / imagemap=on;

proc sgplot data=nasa;
*    waterfall category=president response=NASA_outlay / stat=sum colorgroup=party
        finalbartickvalue="Total Spending"  
        <keyword>=(Total_spending Program) 
        <keyword>=("Total Gov't Spending" "Space Program") 
        tipformat=(Dollar12. <keyword>) ;
    waterfall category=president response=NASA_outlay / stat=sum colorgroup=party
        finalbartickvalue="Total Spending"  
        <keyword>=(Total_spending Program) 
        <keyword>=("Total Gov't Spending" "Space Program") 
        tipformat=(Dollar12. <keyword>) ;
run;

ods graphics / imagemap=off;

