/* 
    Advanced ODS Graphics
    Hands On Workshop

    Solution Set 3

*/
ods html close;

ods graphics / reset=all
	imagename="ODS_Graphics_HOW_3";

ods html path="&homedir.\results" (url=none)
         file="HOW2_graphs.html";   

/* 
    Exercise 3.1

    Attribute Maps

    We will create an attribute map for the data and use it control the style of the lines and markers
	First run the plots to see the default attributes.
*/

proc sgplot data=bond ;
    vbar bjb / response=avg_user_imdb group=bond;
run;

proc sgplot data=bond ;
    vbar martinis / response=avg_user_imdb group=bond;
run;

/*
	Create the attribute map

    Set the ID to "bondm" so that we can use it as the ATTRID for the series plot.
    set the MARKERSYMBOL and LINEPATTERN also. We'll read in the rest of the definitions.

	Notice the color naming scheme. This is one option. You can use the values below to try other colors.

Color Naming System Values 

Lightness  		Saturation  	Hue  
---------------------------------------------
Black  			Gray  			Blue  
Very Dark  		Grayish  		Purple  
Dark  			Moderate  		Red  
Medium  		Strong  		Orange/Brown  
Light  			Vivid  			Yellow  
Very Light   					Green  
White    

SESUG color scheme
#245590, #EE2D7C, #269344, #D9EBFD, #397CC0
*/

data battrmap1;
*    retain <keyword> "bondm";
    retain <keyword> "bondm";
*    retain <keyword> "circlefilled" <keyword> "solid";
    retain <keyword> "circlefilled" <keyword> "solid";
    input value $ 1-14 fillcolor $ 17-40 linecolor $ 45-50 ;
datalines;
Sean Connery    very_light_moderate_blue    red     
Roger Moore     light_moderate_blue			red
Timothy Dalton  medium_moderate_blue  		red
Pierce Brosnan  dark_moderate_blue   		red
Daniel Craig    very_dark_moderate_blue    	red
;;
run;
data battrmap2;
*    retain <keyword> "bondm";
    retain <keyword> "bondm";
*    retain <keyword> "circlefilled" <keyword> "solid";
    retain <keyword> "circlefilled" <keyword> "solid";
    input value $ 1-14 fillcolor $ 17-40 linecolor $ 45-50 ;
datalines;
Sean Connery    #4298B5			    		gray
Roger Moore     #ADC4CC						gray
Timothy Dalton  #92B06A				  		gray
Pierce Brosnan  #E19D29				   		gray
Daniel Craig    #D65C30				    	gray
;;
run;

/* 
    Set the Attribute Map Data Set (DATTRMAP) to either BATTRMAP1 or BATTRMAP2 
    Use 'bondm' as the ATTRID for the series plot.

*/

*proc sgplot data=bond <keyword>=<dataset>;
proc sgplot data=bond <keyword>=battrmap;
*    vbar bjb / response=avg_user_imdb group=bond <keyword>=<variable>;
    vbar bjb / response=avg_user_imdb group=bond <keyword>=<variable>;
run;

*proc sgplot data=bond <keyword>=<dataset>;
proc sgplot data=bond <keyword>=<variable>;
*    vbar martinis / response=avg_user_imdb group=bond <keyword>=<variable>;
    vbar martinis / response=avg_user_imdb group=bond <keyword>=<variable>;
run;

/*
    Exercise 3.2

    We can override the automatic assignment of styles elements to plots in other ways
    
    One is to use the CYCLEATTRS option on the PROC SGPLOT statement
    First run the basic series plot with a needle plot added
         We'll also get rid of the useless legend.
*/

proc sgplot data=bond noautolegend;
    series x=year y=avg_user_imdb ;
    needle x=year y=avg_user_imdb ;
run;

/*
    Now add the CYCLEATTRS option to the PROC statement
    What is different and why?

*/

*proc sgplot data=bond noautolegend <keyword>;
proc sgplot data=bond noautolegend <keyword>;
    series x=year y=avg_user_imdb ;
    needle x=year y=avg_user_imdb ;
run;

/*
    Exercise 3.3

    We can use STYLEATTRS to control the group attributes
    First run the plot to see what the default looks like.

*/

proc sgplot data=bond;
    series x=year y=avg_user_imdb / legendlabel="IMDB" ;
    series x=year y=avg_user_rtn_tom / legendlabel="Rotten Tomatoes";   
    series x=year y=martinis / legendlabel="Martinis";
    series x=year y=bjb / legendlabel="Bond James Bond";
    yaxis label="Movie Statistics"; 
run;

/*
    Now add the STYLEATTRS statement
    The DATACONTRASTCOLORS option is used to color graph elements that are different from each other
    We'll use a DOT pattern and a LONGDASH pattern for the data lines

*/

proc sgplot data=bond;
*    <keyword> <keyword>=(orange blue) datalinepatterns=(<keyword> <keyword>);
    <keyword> <keyword>=(orange blue) datalinepatterns=(<keyword> <keyword>);
    series x=year y=avg_user_imdb / legendlabel="IMDB" ;
    series x=year y=avg_user_rtn_tom / legendlabel="Rotten Tomatoes";   
    series x=year y=martinis / legendlabel="Martinis";
    series x=year y=bjb / legendlabel="Bond James Bond";
    yaxis label="Movie Statistics"; 
run;

/*
    Exercise 3.4
    
    Add blocks with Bond as the BLOCK to show the ratings by actor.

    Try some other patterns and colors to make them show up better

    The names of the actors don't show up very well either. Here are some options
    you can use to control how they look.

    NOVALUES | VALUES
    VALUEATTRS=style-element <(options)> | (options)
    VALUEFITPOLICY=NONE | SHRINK | SPLIT | SPLITALWAYS | TRUNCATE 
    VALUEHALIGN=LEFT | CENTER | RIGHT | START 
    VALUEVALIGN=TOP | CENTER | BOTTOM
    SPLITCHAR=character-list

    Also see the following for help
    SAS System Documentation > SAS Products > Base SAS > ODS Graphics > 
        SAS 9.4 ODS Graphics: Procedures Guide, Third Edition > Procedures > 
        Commonly Used Attribute Options > Text Attributes

*/

proc sgplot data=bond;
    styleattrs datacontrastcolors=(orange blue) datalinepatterns=(dot longdash);
*    <keyword> x=year <keyword>=bond / <add other options here after the first run>  ;
    <keyword> x=year <keyword>=bond;
    series x=year y=avg_user_imdb / legendlabel="IMDB";
    series x=year y=avg_user_rtn_tom / legendlabel="Rotten Tomatoes";   
    yaxis label="Average User Rating"; 
run;

/* 
    Exercise 3.5

    DPI for presentations
    http://blogs.sas.com/content/graphicallyspeaking/2012/05/20/graph-size-for-presentations/

    set the IMAGE_DPI to 150. Try other resolutions

*/

proc sgplot data=bond;
    series x=year y=avg_user_imdb / legendlabel="IMDB";
    series x=year y=avg_user_rtn_tom / legendlabel="Rotten Tomatoes";   
    yaxis  label="Average User Rating"; 
run;

ods html close;

*ods html path="&homedir.\results" (url=none) file="HOW_graphs_pres.html" <keyword>=150;
ods html path="&homedir.\results" (url=none) file="HOW_graphs_pres.html" <keyword>=150;
ods graphics / width=3.5in;

proc sgplot data=bond;
    series x=year y=avg_user_imdb / legendlabel="IMDB";
    series x=year y=avg_user_rtn_tom / legendlabel="Rotten Tomatoes";   
    yaxis  label="Average User Rating"; 
run;

ods html close;
