/* 
    Advanced ODS Graphics
    Hands On Workshop

    Solution Set 1

*/
%let homedir=C:\HOW\kincaid_Interm;

ods graphics / reset=all
	imagename="ODS_Graphics_HOW";

ods html path="&homedir.\results" (url=none)
         file="HOW_graphs.html";   

/*
    Exercise 1.1

    Review: See the basic plot
*/
proc print data=who14;
run;

proc sgplot data=who14;
    scatter x=villain y=episodes;
run;

/*
    Exercise 1.2

    Set up IMAGEMAP to handle URL's
*/

*ods graphics / <keyword>;
 ods graphics / imagemap;

/*
    Exercise 1.3

    Add URL's to the points

    Then go to the html file and see the difference in the output
*/

proc sgplot data=who14;
*    scatter x=villain y=episodes / <keyword>=url;
    scatter x=villain y=episodes / url=url;
run;

/*
    Exercise 1.4

    Make the points bigger and filled in
    SIZE    FILLEDOUTLINEDMARKERS   CIRCLEFILLED
    MARKERATTRS <- controls SYMBOL SIZE COLOR
*/

proc sgplot data=who14;
*    scatter x=villain y=episodes / url=url  <keyword>
            <keyword>=(symbol=<keyword> <keyword>=15);
    scatter x=villain y=episodes / url=url  filledoutlinedmarkers
            markerattrs=(symbol=CircleFilled size=15);
run;

/*
    Exercise 1.5

    Add COLOR (#003865 or another choice)

    SAS System Documentation > SAS Products > Base SAS > ODS Graphics > 
        SAS 9.4 ODS Graphics: Procedures Guide, Third Edition > Procedures > 
        Commonly Used Attributes Options > Color-Naming Schemes

    Try MARKERFILLATTRS <- controls COLOR
    and MARKEROUTLINEATTRS <- controls COLOR and THICKNESS of outline
    Try combinations of those two with and without MARKERATTRS (and options) 
        and FILLEDOUTLINEDMARKERS
    What works and what doesn't?
*/

proc sgplot data=who14;
*    scatter x=villain y=episodes / url=url  filledoutlinedmarkers
            markerattrs=(symbol=CircleFilled size=15) <keyword>=(<keyword>="#003865")
            <keyword>=(color=red);
    scatter x=villain y=episodes / url=url filledoutlinedmarkers
            markerattrs=(symbol=CircleFilled size=15) markerfillattrs=(color="#003865")
            markeroutlineattrs=(color=red);
;
run;

/*
    Exercise 1.6

    Create an annoted data set to include images
    We need the following variables in the dataset
        FUNCTION
        ANCHOR          WIDTH           XC1
        DRAWSPACE       WIDTHUNIT       Y1
        IMAGE           
*/

data dwanno(keep=anchor drawspace image function width widthunit xc1 y1 url);
    set who14;
    length anchor $ 11 drawspace $ 12 image $76;
*    retain <keyword> "Image" <keyword> "center" <keyword> 30 <keyword> "pixel"
            <keyword> "datavalue" ;
    retain function "Image" anchor "center" width 30 widthunit "pixel"
            drawspace "datavalue" ;
*    rename villain=<keyword> episodes=<keyword>;
    rename villain=xc1 episodes=y1;

*    if (villain in ("Borusa", "Cyber-leader", "Cybermat", "Dalek Supreme", "Goth", "The Master")) 
        then <keyword> = cats("&homedir.\images\",villain,".jpg");
    if (villain in ("Borusa", "Cyber-leader", "Cybermat", "Dalek Supreme", "Goth", "The Master")) 
        then image = cats("&homedir.\images\",villain,".jpg");
*        else <keyword> = cats("&homedir.\images\",villain,".png");
        else image = cats("&homedir.\images\",villain,".png");
run;

/*
    Exercise 1.7
	Now add the Annotation to the SG plot SGANNO
*/

*proc sgplot data=who14 <keyword>=dwanno;
proc sgplot data=who14 sganno=dwanno;
    scatter x=villain y=episodes / filledoutlinedmarkers
            markerattrs=(symbol=CircleFilled size=15);
    format villain;
run;

/*
    Then turn the IMAGEMAP=OFF so that there is NOIMAGEMAP (either way works)
*/

*ods graphics / <keyword>;
ods graphics / noimagemap;

/*
    Exercise 1.8

    Add tables to the plot
    We'll add one at a time using the scatter statement first
 
    use the character variables X1 X2 and X3 as the points on the Y2AXIS
    set the MARKERCHAR to be the values you want to display

    The OFFSETMIN and OFFSETMAX have to be set to allow both sets of scatter plots
    to be displayed without overlapping. As you add new tables, modify the values for
	these parameters to understand how they interact

    After that plot add COLORBANDS=EVEN or ODD to the XAXIS

    Why do we have the NOAUTOLEGEND option?
*/

data who14;
    set who14;
    x1 = "First Aired";
    x2 = "Total Storylines";
    x3 = "Last Aired";
run;

proc sgplot data=who14 noautolegend;
    scatter x=villain y=episodes; 

*    scatter x=villain y=<variable> / <keyword>=year_first <keyword>;
    scatter x=villain y=x1 / markerchar=year_first y2axis;

*    yaxis <keyword>=0.1 <keyword>=0.05;
    yaxis offsetmin=0.1 offsetmax=0.05;
*    y2axis display=(nolabel) <keyword>=0.8;
    y2axis display=(nolabel)  offsetmax=0.9;
run;

/* 
	now with two tables. What should the offsets be?
	make sure you put the right variable in for the markerchar
*/

proc sgplot data=who14 noautolegend;
    scatter x=villain y=episodes; 
    scatter x=villain y=x1 / markerchar=year_first y2axis;
*    scatter x=villain y=x2 / markerchar=<variable> y2axis;
    scatter x=villain y=x2 / markerchar=total_stories y2axis;

    yaxis offsetmin=0.2 offsetmax=0.05;
    y2axis display=(nolabel) offsetmin=0.05 offsetmax=0.9;
run;

/* 
	Just to make sure you have it, what should it be with three tables.
*/

proc sgplot data=who14 noautolegend;
    scatter x=villain y=episodes; 
    scatter x=villain y=x1 / markerchar=year_first y2axis;
    scatter x=villain y=x2 / markerchar=total_stories y2axis;
    scatter x=villain y=x3 / markerchar=total_stories y2axis;

    yaxis offsetmin=0.2 offsetmax=0.05;
    y2axis display=(nolabel) offsetmin=0.05 offsetmax=0.85;
run;
/*
    Exercise 1.9

    Add XAXISTABLE to the INSIDE of the scatterplot
    What does it look like on the outside (default)?

    Other options you may want to try
    SEPARATOR
    TITLE="Showing Stats"
    X2AXIS          -|  What's the difference between these two?
    POSITION=TOP    -|

*/

proc sgplot data=who14;
    scatter x=villain y=episodes;
*    <keyword> year_last total_stories year_first / location=<keyword>;
    xaxistable year_last total_stories year_first / location=inside ;
run;

/*
    Exercise 1.10

    Include tables with a CLASS variable

*/

data who_class(keep=villain year end episodes total_stories);
    set who14;
    year = year_first;
    end = "First Aired";
    output;
    year = year_last;
    end = "Last Aired";
    output;
run;

proc sgplot data=who_class;
    scatter x=villain y=episodes; 
*    xaxistable year / <keyword>=end location=inside ;
    xaxistable year / class=end location=inside ;
run;

